@@ -5,17 +5,22 @@ import pydantic
 
 
 class _SettingsModel(pydantic.BaseSettings):
+    # Network
     base_domain: str = "compass.scouts.org.uk"
-    base_url: pydantic.HttpUrl = f"https://{base_domain}"  # type: ignore[assignment]
-    date_format: str = "%d %B %Y"  # dd Month YYYY
-    org_number: int = 10000001
-    total_requests: int = 0
     wcf_json_endpoint: str = "/JSon.svc"  # Windows communication foundation JSON service endpoint
+    secure_connection: bool = True
+    base_url: pydantic.HttpUrl = f"http{'s' if secure_connection else ''}://{base_domain}"  # type: ignore[assignment]
     web_service_path: pydantic.HttpUrl = base_url + wcf_json_endpoint  # type: ignore[assignment]
+    # Requests
+    total_requests: int = 0
+    # Application
+    org_number: int = 10000001
+    date_format: str = "%d %B %Y"  # dd Month YYYY
+    # Environment
     debug: bool = False
-    validation_errors: bool = True
     log_file: Optional[Path] = None
-    cache_to_file: bool = True
+    use_cache: bool = False
+    validation_errors: bool = True
 
     class Config:
         case_sensitive = False  # this is the default, but mark for clarity.
